@@ -13,8 +13,8 @@ class IChannel:
     name: str
     debug: bool
 
-    def __init__(self, name: str, debug: bool = False):
-        self.name = name
+    def __init__(self, wroker_name: str, debug: bool = False):
+        self.name = wroker_name
         self.debug = debug
         self.produce_pipe = IsolatePipes(AioQueue(), AioEvent(), AioLock())
         self.consume_pipe = IsolatePipes(AioQueue(), AioEvent(), AioLock())
