@@ -7,13 +7,13 @@ from web_foundation.workers.worker import Worker
 
 class TaskExecutor(Worker):
 
-    def sync_run(self):
-        pass
-
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-    async def async_run(self):
+    def _configure(self, *args, **kwargs):
+        pass
+
+    async def _run(self):
         await self.channel.listen_consume(self.task_handler)
 
     async def task_handler(self, message: TaskIMessage):
@@ -26,3 +26,6 @@ class TaskExecutor(Worker):
 
     def produce_response(self, resp: Task):
         asyncio.create_task(self.channel.produce(resp.result()))
+
+    def _close(self,*args,**kwargs):
+        pass
