@@ -7,8 +7,8 @@ from web_foundation.kernel import Isolate
 class Worker(Isolate):
     _initiators: List[Initiator]
 
-    def __init__(self, async_mode: bool = False, debug: bool = False):
-        super().__init__(async_mode, debug)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self._initiators = []
 
     @property
@@ -19,6 +19,12 @@ class Worker(Isolate):
     def initiators(self, value: List[Initiator]):
         self._initiators = value
 
-    async def on_isolate_up(self, initiators: List[Initiator]):
+    async def initiate_on_up(self, initiators: List[Initiator]):
         for init in initiators:
             await init.setup_connection(self.ctx)
+
+    async def _run(self):
+        raise NotImplementedError
+
+    def _close(self):
+        pass
